summaryrefslogtreecommitdiffstats
path: root/web/gui/src/dashboard.js/main.js
diff options
context:
space:
mode:
Diffstat (limited to 'web/gui/src/dashboard.js/main.js')
-rw-r--r--web/gui/src/dashboard.js/main.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/web/gui/src/dashboard.js/main.js b/web/gui/src/dashboard.js/main.js
index c1cfba5e5..a638b4e99 100644
--- a/web/gui/src/dashboard.js/main.js
+++ b/web/gui/src/dashboard.js/main.js
@@ -1432,7 +1432,7 @@ let chartState = function (element) {
if (NETDATA.options.current.show_help) {
if (this.element_legend_childs.toolbox !== null) {
if (this.debug) {
- this.log('hideChart(): hidding legend popovers');
+ this.log('hideChart(): hiding legend popovers');
}
$(this.element_legend_childs.toolbox_left).popover('hide');
@@ -2979,7 +2979,7 @@ let chartState = function (element) {
}
}
// create a hidden div to be used for hidding
// the original legend of the chart library
let el = document.createElement('div');
if (this.element_legend !== null) {
@@ -2979,7 +2979,7 @@ let chartState = function (element) {
}
}
- // create a hidden div to be used for hidding
+ // create a hidden div to be used for hiding
// the original legend of the chart library
let el = document.createElement('div');